MaybeSwitch

Struct MaybeSwitch 

pub struct MaybeSwitch {
    pub switch_to: Option<String>,
    pub vars: Vec<(String, String)>,
}

Fields

switch_to: Option<String>

If non-empty, this indicates that the receiving attach process should hang up, then reattach to the given session name.

Session switching is incompatible with session name templates, so the attach process should exit and display an error to the user if it gets a MaybeSwitch telling to to switch to a specific session name.

vars: Vec<(String, String)>

The shpool wide variable environment. The attach process should hang up and reattach if it has a session name template which produces a new result with this new environment.